wmd

package
v0.0.0-...-d7aea0d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2018 License: MIT Imports: 4 Imported by: 0

README

Word Mover Distance

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Wmd

func Wmd(d1, d2 []string, m *w2v.Model) (float64, error)

returns the word-move-distance between the given two words slice if one of the words slice doesn't have any word in the model then this function returns math.Inf(1).

Types

This section is empty.

Jump to